OC.L10N.register(
    "core",
    {
    "Please select a file." : "Välj en fil.",
    "File is too big" : "Filen är för stor",
    "The selected file is not an image." : "Den valda filen är ingen bild.",
    "The selected file cannot be read." : "Den valda filen kan inte läsas.",
    "The file was uploaded" : "Filen har laddats upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uppladdade filen är större än vad som tillåts av upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-direktivet som specificerades i HTML-formuläret",
    "The file was only partially uploaded" : "Filen är endast delvist uppladdad",
    "No file was uploaded" : "Ingen fil laddades upp",
    "Missing a temporary folder" : "Saknar en tillfällig mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdningen",
    "Invalid file provided" : "En ogiltig fil tillhandahölls",
    "No image or file provided" : "Ingen bild eller fil har tillhandahållits",
    "Unknown filetype" : "Okänd filtyp",
    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
    "Invalid image" : "Ogiltig bild",
    "No temporary profile picture available, try again" : "Ingen temporär profilbild finns tillgänglig, försök igen",
    "No crop data provided" : "Inga beskärningsdata har angivits",
    "No valid crop data provided" : "Ingen giltig beskärningsdata tillhandahölls",
    "Crop is not square" : "Beskärning är inte kvadratisk",
    "State token does not match" : "Tillstånds-token matchar inte",
    "Invalid app password" : "Felaktigt app-lösenord",
    "Could not complete login" : "Kunde inte slutföra inloggningen",
    "State token missing" : "Statustoken saknas",
    "Your login token is invalid or has expired" : "Din inloggnings-token är ogiltigt eller har gått ut",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Denna community-release av Nextcloud stöds inte och pushnotifikationer är begränsade.",
    "Login" : "Logga in",
    "Please try again" : "Var vänlig och försök igen",
    "Password reset is disabled" : "Lösenordsåterställning är avaktiverat",
    "Could not reset password because the token is expired" : "Kunde inte återställa lösenord eftersom token har utgått",
    "Could not reset password because the token is invalid" : "Kunde inte återställa lösenord eftersom token är ogiltigt",
    "Password is too long. Maximum allowed length is 469 characters." : "Lösenordet är för långt. Högsta tillåtna längd är 469 tecken.",
    "%s password reset" : "%s återställ lösenord",
    "Password reset" : "Lösenordsåterställning",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på knappen för att återställa ditt lösenord.  Om du inte har begärt att återställa ditt lösenord så kan du ignorera detta epost, inget kommer då att ske.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på länken för att återställa ditt lösenord. Om du inte har begärt att lösenordet ska återställas så kan du ignorera detta epost.",
    "Reset your password" : "Återställ ditt lösenord",
    "No translation provider available" : "Ingen översättning tillgänglig",
    "Could not detect language" : "Kunde inte identifiera språk",
    "Unable to translate" : "Kan inte översätta",
    "Nextcloud Server" : "Nextcloud-server",
    "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
    "The user limit of this instance is reached." : "Maximala användarantalet för denna instansen har uppnåts",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ange din prenumerationsnyckel i supportappen för att öka användargränsen. Detta ger dig också alla ytterligare fördelar som Nextcloud Enterprise erbjuder och rekommenderas starkt för användning i företag.",
    "Learn more ↗" : "Läs mer ↗",
    "Preparing update" : "Förbereder uppdatering",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Reparationssteg: ",
    "Repair info:" : "Reparationsinfo:",
    "Repair warning:" : "Reperationsvarning:",
    "Repair error:" : "Reperationsfel:",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Var vänlig och uppdatera via kommandotolken då uppdatering via webbläsaren är inaktiverat i config.php",
    "Turned on maintenance mode" : "Aktiverade underhållsläge",
    "Turned off maintenance mode" : "Inaktivera underhållsläge",
    "Maintenance mode is kept active" : "Underhållsläget förblir aktiverat",
    "Updating database schema" : "Uppdaterar databasschema",
    "Updated database" : "Uppdaterade databasen",
    "Update app \"%s\" from App Store" : "Uppdatera appen \"%s\" från appbutiken",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kontrollerar om databasschema för %s kan uppdateras (detta kan ta lång tid beroende på databasens storlek)",
    "Updated \"%1$s\" to %2$s" : "Uppdaterade \"%1$s\" till %2$s",
    "Set log level to debug" : "Sätter loggningsnivå till \"debug\"",
    "Reset log level" : "Återställer loggningsnivå",
    "Starting code integrity check" : "Startar integritetskontroll av kod",
    "Finished code integrity check" : "Slutförde integritetskontroll av kod",
    "%s (incompatible)" : "%s (inkompatibel)",
    "The following apps have been disabled: %s" : "Följande appar har inaktiverats: %s",
    "Already up to date" : "Redan uppdaterad",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webbserver är ännu inte korrekt inställd för att tillåta filsynkronisering, eftersom WebDAV-gränssnittet verkar vara trasigt.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Din webbserver är inte korrekt inställd för att lösa \"{url}\". Ytterligare information finns i {linkstart}dokumentationen ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Din webbserver är inte korrekt inställd för att lösa \"{url}\". Detta är troligen relaterat till en webbserverkonfiguration som inte uppdaterades för att leverera den här mappen direkt. Vänligen jämför din konfiguration med de skickade omskrivningsreglerna i \".htaccess\" för Apache eller den som tillhandahålls i dokumentationen för Nginx på dess {linkstart}dokumentationssida ↗{linkend}. På Nginx är det vanligtvis raderna som börjar med \"plats ~\" som behöver en uppdatering.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Din webbserver är inte korrekt inställd för att leverera .woff2-filer. Detta är vanligtvis ett problem med Nginx-konfigurationen. För Nextcloud 15 behöver det en justering för att även leverera .woff2-filer. Jämför din Nginx-konfiguration med den rekommenderade konfigurationen i vår {linkstart}dokumentation ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP verkar inte vara korrekt inställd för att fråga efter systemmiljövariabler. Testet med getenv(\"PATH\") ger bara ett tomt svar.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Vänligen kontrollera {linkstart}installationsdokumentationen ↗{linkend} för PHP-konfigurationsanteckningar och PHP-konfigurationen för din server, speciellt när du använder php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Den skrivskyddade konfigurationen har aktiverats. Detta förhindrar att vissa konfigurationer ställs in via webbgränssnittet. Dessutom måste filen göras skrivbar manuellt för varje uppdatering.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Du har inte ställt in eller verifierat din e-postserverkonfiguration ännu. Gå över till {mailSettingsStart}Grundläggande inställningar{mailSettingsEnd} för att ställa in dem. Använd sedan knappen \"Skicka e-post\" under formuläret för att verifiera dina inställningar.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Databasen körs inte med transaktionsisoleringsnivån \"READ COMMITTED\". Det kan orsaka problem när flera aktiviteter körs parallellt.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP-modulen \"fileinfo\" saknas. Det rekommenderas starkt att göra det möjligt för den här modulen att få bästa resultat med MIME-typdetektering.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transaktionsfillåsning är inaktiverad, detta kan leda till problem med. Aktivera \"filelocking.enabled\" i config.php för att undvika dessa problem. Se {linkstart}dokumentationen ↗{linkend} för mer information.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Se till att ställa in konfigurationsalternativet \"overwrite.cli.url\" i din config.php-fil till den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Förslag: \"{suggestedOverwriteCliURL}\". Annars kan det uppstå problem med URL-genereringen via cron. (Det är dock möjligt att den föreslagna URL:en inte är den URL som dina användare huvudsakligen använder för att komma åt detta Nextcloud. Bäst är att dubbelkolla detta i alla fall.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Din installation har ingen standardtelefonregion inställd. Detta krävs för att validera telefonnummer i profilinställningarna utan landskod. För att tillåta nummer utan landskod, lägg till \"default_phone_region\" med respektive {linkstart}ISO 3166-1-kod ↗{linkend} för regionen i din konfigurationsfil.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Det var inte möjligt att utföra cron-jobbet via CLI. Följande tekniska fel har uppstått:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Senaste bakgrundsjobbet kördes {relativeTime}. Något verkar fel. {linkstart}Kontrollera inställningarna för bakgrundsjobb ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Detta är Nextclouds communitybygge utan support från Nextcloud GmbH. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har begränsats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Den här servern har ingen fungerande internetanslutning: Flera slutpunkter kunde inte nås. Det betyder att vissa av funktionerna som montering av extern lagring, aviseringar om uppdateringar eller installation av tredjepartsappar inte kommer att fungera. Att komma åt filer på distans och skicka e-postmeddelanden kanske inte heller fungerar. Upprätta en anslutning från denna server till internet för att kunna nyttja alla funktioner.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Inget minnescache har konfigurerats. För att förbättra prestandan, vänligen konfigurera en memcache, om tillgänglig. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen lämplig källa för slumpmässighet hittas av PHP, Detta avråder vi från starkt på grund av säkerhetsskäl. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Du kör för nuvarande PHP {version}. Uppgradera din PHP version för att dra nytta av {linkstart}prestanda och säkerhetsuppdateringar tillhandahållna av PHP Group ↗{linkend} så snart din servermiljö stödjer det.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfigurationen av den omvända proxyhuvudet är felaktig, eller så använder du Nextcloud från en betrodd proxy. Om inte, är detta ett säkerhetsproblem och kan tillåta en angripare att förfalska sin IP-adress som synlig för Nextcloud. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Några filer har inte klarat integritetskontrollen. Vidare information om hur man löser detta problem kan hittas i {linkstart1}dokumentationen↗{linkend}. ({linkstart2}Lista med de ogiltiga filerna…{linkend} / {linkstart3}Scanna igen…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modulen är felaktigt inställd. Se {linkstart}dokumentationen ↗{linkend} för mer information",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Saknar index \"{indexName}\" i tabellen \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
    "Missing primary key on table \"{tableName}\"." : "Saknar primärnyckel i tabellen \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen saknar några primärnycklar. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-primary-keys\" läggs de saknade primärnycklarna till utan att instansen behöver stoppas.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Saknar den valfria kolumnen \"{columnName}\" i tabell \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen saknar några valfria kolumner. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-columns\" läggs de saknade kolumnerna till utan att instansen behöver stoppas. Att lägga till de valfria kolumnerna kan förbättra svarstid eller användbarhet.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instansen saknar några rekommenderade PHP-moduler. För förbättrad prestanda och kompatibilitet är det starkt rekommenderat att installera dem.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modulen php-image har i det här fallet inget SVG-stöd. För bättre kompatibilitet rekommenderas det att installera det.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite används som databas. För större installationer så rekommenderar vi ett byte till en annan databasbackend.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Detta rekommenderas särskilt när du använder skrivbordsklienten för filsynkronisering.",
    "The PHP memory limit is below the recommended value of 512MB." : "Minnesgränsen för PHP är under det rekommenderade värdet på 512 MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Vissa appkataloger ägs av en annan användare än den som äger webbservern. Detta kan vara fallet om appar har installerats manuellt. Kontrollera behörigheterna för följande appkataloger:",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Den tillfälliga katalogen för denna instans pekar på en icke-existerande eller icke-skrivbar katalog.",
    "Error occurred while checking server setup" : "Ett fel inträffade när en kontroll av serverns konfiguration utfördes",
    "For more details see the {linkstart}documentation ↗{linkend}." : "För mer detaljer se {linkstart}dokumentationen ↗{linkend}.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Detta är en potentiell säkerhets- eller sekretessrisk, eftersom det rekommenderas att justera denna inställning i enlighet med detta.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" är inte inställd till \"{expected}\". Vissa funktioner kanske inte fungerar korrekt, eftersom det rekommenderas att justera den här inställningen i enlighet med detta.",
    "unknown text" : "okänd text",
    "Hello world!" : "Hej världen!",
    "sunny" : "soligt",
    "Hello {name}, the weather is {weather}" : "Hej {name}, vädret är {weather}",
    "Hello {name}" : "Hej {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Detta är ditt sökresultat<script>alert(1)</script></strong>",
    "new" : "ny",
    "_download %n file_::_download %n files_" : ["Ladda ner %n fil","Hämta %n filer"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppdateringen pågår, om sidan lämnas kan uppdateringen misslyckas. ",
    "Update to {version}" : "Uppdatera till {version}",
    "An error occurred." : "Ett fel inträffade.",
    "Please reload the page." : "Uppdatera sidan.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uppdateringen misslyckades. För mer information <a href=\"{url}\">se vår forumpost</a> angående problemet.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uppdateringen misslyckades. Rapportera felet till <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
    "Continue to {productName}" : "Fortsätt till {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekund.","Uppdateringen lyckades. Omdirigerar dig till {productName} om %n sekunder."],
    "More apps" : "Fler appar",
    "Currently open" : "För närvarande öppen",
    "_{count} notification_::_{count} notifications_" : ["{count} meddelande","{count} meddelanden"],
    "Log in" : "Logga in",
    "Logging in …" : "Loggar in ...",
    "Server side authentication failed!" : "Servern misslyckades med autentisering!",
    "Please contact your administrator." : "Kontakta din administratör.",
    "An internal error occurred." : "Ett internt fel uppstod.",
    "Please try again or contact your administrator." : "Försök igen eller kontakta din administratör.",
    "Account name or email" : "Användarnamn eller e-post",
    "Password" : "Lösenord",
    "Log in to {productName}" : "Logga in på {productName}",
    "Wrong username or password." : "Felaktigt användarnamn eller lösenord",
    "User disabled" : "Användare inaktiverad",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
    "Username or email" : "Användarnamn eller e-post",
    "Your account is not setup for passwordless login." : "Ditt konto är inte inställt för inloggning utan lösenord.",
    "Browser not supported" : "Webbläsaren stöds inte",
    "Passwordless authentication is not supported in your browser." : "Lösenordsfri autentisering stöds inte i din webbläsare.",
    "Your connection is not secure" : "Din anslutning är inte säker",
    "Passwordless authentication is only available over a secure connection." : "Lösenordsfri autentisering är endast tillgänglig via en säker anslutning.",
    "Reset password" : "Återställ lösenord",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Om det här kontot finns har ett meddelande om lösenordsåterställning skickats till dess e-postadress. Om du inte får det, verifiera din e-postadress och/eller kontonamn, kontrollera dina skräppost-/skräpmappar eller be din lokala administration om hjälp.",
    "Couldn't send reset email. Please contact your administrator." : "Kunde inte skicka återställningsmejl. Kontakta din administratör.",
    "Password cannot be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
    "Back to login" : "Tillbaka till inloggning",
    "New password" : "Nytt lösenord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord har återställs. Om du är osäker på hur du ska göra, kontakta din administratör innan du fortsätter. Är du verkligen säker på att du vill fortsätta?",
    "I know what I'm doing" : "Jag vet vad jag gör",
    "Resetting password" : "Återställer lösenord",
    "Recommended apps" : "Rekommenderade appar",
    "Loading apps …" : "Läser in appar …",
    "Could not fetch list of apps from the App Store." : "Det gick inte att hämta listan över appar från App Store.",
    "Installing apps …" : "Installerar appar ...",
    "App download or installation failed" : "Hämtning eller installation av appen misslyckades",
    "Cannot install this app because it is not compatible" : "Appen kan inte installeras eftersom den inte är kompatibel",
    "Cannot install this app" : "Kan inte installera denna app",
    "Skip" : "Hoppa över",
    "Install recommended apps" : "Installera rekommenderade appar",
    "Schedule work & meetings, synced with all your devices." : "Planera arbete och möten, synkronisera med alla dina enheter.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Håll dina kollegor och vänner på ett ställe utan att läcka deras privata info.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app integrerad med filer, kontakter och kalender.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatt, videosamtal, skärmdelning, onlinemöten och webbkonferenser – i din webbläsare och med mobilappar.",
    "Search contacts" : "Sök kontakter",
    "Forgot password?" : "Glömt lösenordet?",
    "Log in with a device" : "Logga in med en enhet",
    "Back" : "Tillbaka",
    "Login form is disabled." : "Inloggningsfomuläret är inaktiverat.",
    "Edit Profile" : "Redigera profil",
    "The headline and about sections will show up here" : "Rubriken och avsnitten \"om\" kommer att dyka upp här",
    "You have not added any info yet" : "Du har inte angivit någon information ännu",
    "{user} has not added any info yet" : "{user} har inte angivit någon information ännu",
    "Error opening the user status modal, try hard refreshing the page" : "Kunde inte öppna användarstatus-rutan, försök att ladda om sidan",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Sökningen startar när du börjar skriva och resultat kan nås med piltangenterna",
    "Reset search" : "Återställ sökning",
    "Start search" : "Starta sökning",
    "Search for {name} only" : "Sök efter endast {name}",
    "Start typing to search" : "Börja skriva för att söka",
    "Loading more results …" : "Hämtar fler resultat ...",
    "Load more results" : "Hämta fler resultat",
    "Search" : "Sök",
    "No results for {query}" : "Inga resultat för {query}",
    "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Ange {minSearchLength} tecken eller mer för att söka","Ange {minSearchLength} tecken eller mer för att söka"],
    "This browser is not supported" : "Den här webbläsaren stöds inte",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din webbläsare stöds inte. Uppgradera till en nyare version eller en som stöds.",
    "Continue with this unsupported browser" : "Fortsätt med webbläsare som inte stöds",
    "Supported versions" : "Stödda versioner",
    "{name} version {version} and above" : "{name} version {version} och högre",
    "Open settings menu" : "Öppna inställningsmenyn",
    "Settings menu" : "Inställningsmeny",
    "Search {types} …" : "Sök {types} …",
    "Settings" : "Inställningar",
    "Avatar of {fullName}" : "Avatar för {fullName}",
    "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
    "Search contacts …" : "Sök kontakter ...",
    "No contacts found" : "Inga kontakter hittades",
    "Show all contacts …" : "Visa alla kontakter ...",
    "Install the Contacts app" : "Installera appen Kontakter",
    "Loading your contacts …" : "Läser in dina kontakter ...",
    "Looking for {term} …" : "Letar efter {term} …",
    "No" : "Nej",
    "Yes" : "Ja",
    "No files in here" : "Det finns inga filer här",
    "New folder" : "Ny mapp",
    "No more subfolders in here" : "Inga fler undermappar här",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamnet kan inte vara tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "{newName} already exists" : "{newName} existerar redan",
    "Choose" : "Välj",
    "Copy" : "Kopiera",
    "Move" : "Flytta",
    "Error loading file picker template: {error}" : "Fel uppstod för filväljarmall: {error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
    "read-only" : "skrivskyddad",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} filkonflikt","{count} filkonflikter"],
    "One file conflict" : "En filkonflikt",
    "New Files" : "Nya filer",
    "Already existing files" : "Filer som redan existerar",
    "Which files do you want to keep?" : "Vilka filer vill du behålla?",
    "If you select both versions, the copied file will have a number added to its name." : "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
    "Cancel" : "Avbryt",
    "Continue" : "Fortsätt",
    "(all selected)" : "(Alla valda)",
    "({count} selected)" : "({count} valda)",
    "Error loading file exists template" : "Fel vid inläsning av fil finns i mall",
    "Show list view" : "Visa listvy",
    "Show grid view" : "Visa rutnätsvy",
    "Pending" : "Väntar",
    "Home" : "Hem",
    "Copy to {folder}" : "Kopiera till {folder}",
    "Move to {folder}" : "Flytta till {folder}",
    "Saving …" : "Sparar ...",
    "Authentication required" : "Autentisering krävs",
    "This action requires you to confirm your password" : "Denna åtgärd kräver att du bekräftar ditt lösenord",
    "Confirm" : "Bekräfta",
    "Failed to authenticate, try again" : "Misslyckades att autentisera, försök igen",
    "seconds ago" : "sekunder sedan",
    "Connection to server lost" : "Anslutning till server förlorad",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem med att läsa in sidan, uppdaterar om %n sekund","Problem med att läsa in sidan, uppdaterar om %n sekunder"],
    "Add to a project" : "Lägg till i ett projekt",
    "Show details" : "Visa detaljer",
    "Hide details" : "Göm detaljer",
    "Rename project" : "Byt namn på projekt",
    "Failed to rename the project" : "Kunde inte byta namn på projektet",
    "Failed to create a project" : "Kunde inte skapa projekt",
    "Failed to add the item to the project" : "Kunde inte att lägga till objektet i projektet",
    "Connect items to a project to make them easier to find" : "Länka objekt till ett projekt för att göra dem enklare att hitta",
    "Type to search for existing projects" : "Skriv för att söka efter befintliga projekt",
    "New in" : "Ny i",
    "View changelog" : "Visa ändringslogg",
    "Very weak password" : "Väldigt svagt lösenord",
    "Weak password" : "Svagt lösenord",
    "So-so password" : "Okej lösenord",
    "Good password" : "Bra lösenord",
    "Strong password" : "Starkt lösenord",
    "No action available" : "Ingen åtgärd tillgänglig",
    "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
    "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
    "Restricted" : "Begränsad",
    "Invisible" : "Osynlig",
    "Delete" : "Ta bort",
    "Rename" : "Byt namn",
    "Collaborative tags" : "Samverkanstaggar",
    "No tags found" : "Hittade inga taggar",
    "Personal" : "Personliga Inställningar",
    "Users" : "Användare",
    "Apps" : "Appar",
    "Admin" : "Admin",
    "Help" : "Hjälp",
    "Access forbidden" : "Åtkomst förbjuden",
    "Profile not found" : "Profil kunde inte hittas",
    "The profile does not exist." : "Profilen existerar inte.",
    "Back to %s" : "Tillbaka till %s",
    "Page not found" : "Sidan hittades inte",
    "The page could not be found on the server." : "Sidan kunde inte hittas på servern.",
    "Too many requests" : "För många förfrågningar",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
    "Error" : "Fel",
    "Previous" : "Föregående",
    "Internal Server Error" : "Internt serverfel",
    "The server was unable to complete your request." : "Servern kunde inte slutföra din begäran.",
    "If this happens again, please send the technical details below to the server administrator." : "Om det händer igen, vänligen skicka de tekniska detaljerna nedan till din serveradministratör.",
    "More details can be found in the server log." : "Mer detaljer återfinns i serverns logg.",
    "Technical details" : "Tekniska detaljer",
    "Remote Address: %s" : "Extern adress: %s",
    "Request ID: %s" : "Begärd ID: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "Meddelande: %s",
    "File: %s" : "Fil: %s",
    "Line: %s" : "Rad: %s",
    "Trace" : "Spåra",
    "Security warning" : "Säkerhetsvarning",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din datakatalog och filer är förmodligen tillgängliga från Internet eftersom filen .htaccess inte fungerar.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Information hur din server bäst konfigureras kan hittas i <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
    "Create an <strong>admin account</strong>" : "Skapa ett <strong>administratörskonto</strong>",
    "Username" : "Användarnamn",
    "Show password" : "Visa lösenord",
    "Toggle password visibility" : "Växla lösenordsynlighet",
    "Storage & database" : "Lagring & databas",
    "Data folder" : "Datamapp",
    "Configure the database" : "Konfigurera databasen",
    "Only %s is available." : "Endast %s är tillgänglig.",
    "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
    "For more details check out the documentation." : "För mer detaljer se dokumentationen",
    "Database user" : "Databasanvändare",
    "Database password" : "Lösenord till databasen",
    "Database name" : "Databasnamn",
    "Database tablespace" : "Databas tabellutrymme",
    "Database host" : "Databasserver",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
    "Performance warning" : "Prestandavarning",
    "You chose SQLite as database." : "Du valde SQLite som databas.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bör endast användas till små installationer och installationer avsedda för utveckling. För produktion rekommenderar vi byte till annan databas.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Om du använder synkklienter avråder vi starkt från användning av SQLite.",
    "Install" : "Installera",
    "Installing …" : "Installerar …",
    "Need help?" : "Behövs hjälp?",
    "See the documentation" : "Se dokumentationen",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som att du försöker installera om Nextcloud. Men filen CAN_INSTALL saknas i din konfigurationskatalog. Skapa filen CAN_INSTALL i din konfigurationsmapp för att fortsätta.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Det gick inte att ta bort CAN_INSTALL från konfigurationsmappen. Ta bort den här filen manuellt.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. {linkstart}aktivera JavaScript{linkend} och uppdatera sidan.",
    "Skip to main content" : "Skippa till huvudinnehållet",
    "Skip to navigation of app" : "Skippa till navigering av app",
    "Get your own free account" : "Skaffa ett eget gratiskonto",
    "Go to %s" : "Gå till %s",
    "Confirm your password" : "Bekräfta ditt lösenord",
    "Connect to your account" : "Anslut ditt konto",
    "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Om du inte försöker konfigurera en ny enhet eller app, försöker någon lura dig att ge dem åtkomst till din data. Fortsätt i så fall inte, utan kontakta istället din systemadministratör.",
    "App token" : "Apptoken",
    "Grant access" : "Tillåt åtkomst",
    "Alternative log in using app token" : "Alternativ inloggning med apptoken",
    "Account access" : "Kontoåtkomst",
    "Currently logged in as %1$s (%2$s)." : "För närvarande inloggad som %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Du håller på att ge %1$s åtkomst till ditt %2$s konto.",
    "Account connected" : "Konto anslutet",
    "Your client should now be connected!" : "Din klient ska nu vara ansluten!",
    "You can close this window." : "Du kan stänga det här fönstret.",
    "This share is password-protected" : "Denna delning är lösenordsskyddad",
    "The password is wrong or expired. Please try again or request a new one." : "Lösenordet är fel eller har gått ut. Försök igen eller begär ett nytt.",
    "Please type in your email address to request a temporary password" : "Skriv in din e-postadress för att begära ett tillfälligt lösenord",
    "Email address" : "E-postadress",
    "Password sent!" : "Lösenord skickat!",
    "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
    "Two-factor authentication" : "Tvåfaktorsautentisering",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Det gick inte att läsa in minst en av dina aktiverade tvåfaktorsautentiseringsmetoder. Vänligen kontakta din systemadministratören.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Kontakta din administratör för hjälp.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Fortsätt och konfigurera tvåfaktorsautentisering.",
    "Set up two-factor authentication" : "Ställ in tvåfaktorsautentisering",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tvåfaktorsautentisering krävs men har inte konfigurerats för ditt konto. Använd en av dina säkerhetskoder för att logga in eller kontakta din administratör för hjälp.",
    "Use backup code" : "Använd reservkod",
    "Cancel login" : "Avbryt inloggning",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj vilken leverantör du vill konfigurera:",
    "Error while validating your second factor" : "Fel vid verifiering av tvåfaktorsautentisering.",
    "Access through untrusted domain" : "Åtkomst genom obetrodd domän",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Vänligen kontakta din administratör. Om du är en administratör, ändra \"trusted_domains\"-inställningen i config/config.php likt exemplet i config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Ytterligare information hur du konfigurerar detta finns i %1$sdokumentationen%2$s.",
    "App update required" : "Appen behöver uppdateras",
    "%1$s will be updated to version %2$s" : "%1$s kommer att uppdateras till version %2$s",
    "The following apps will be updated:" : "Följande appar kommer att uppdateras:",
    "These incompatible apps will be disabled:" : "Dessa inkompatibla appar kommer att inaktiveras",
    "The theme %s has been disabled." : "Temat  %s har blivit inaktiverat.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Säkerställ att en säkerhetskopia har gjorts av databasen, konfigurations- och datamappen innan du fortsätter.",
    "Start update" : "Påbörja uppdateringen",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "För att undvika timeout vid större installationer kan du istället köra följande kommando från din installationskatalog:",
    "Detailed logs" : "Detaljerade loggar",
    "Update needed" : "Uppdatering krävs",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Vänligen uppdatera med kommando eftersom du har en stor instans med mer än 50 användare.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Uppdatera via kommandotolken då automatisk uppdatering är inaktiverat i config.php.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "För hjälp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentationen</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jag vet att om jag fortsätter göra uppdateringen via webbgränssnittet innebär risken att begäran får timeout och kan orsaka dataförluster men att jag har en backup och vet hur instansen återställs i fall fel uppstår.",
    "Upgrade via web on my own risk" : "Uppgradera via webben på min egen risk",
    "Maintenance mode" : "Underhållsläge",
    "This %s instance is currently in maintenance mode, which may take a while." : "Denna %s-instans befinner sig för närvarande i underhållsläge, vilket kan ta ett tag.",
    "This page will refresh itself when the instance is available again." : "Denna sida uppdaterar sig själv när instansen är tillgänglig igen.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hör av dig till din systemadministratör om detta meddelande fortsätter eller visas oväntat.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Kontrollerar tabell %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Detta är Nextclouds communitybygge som inte supporteras. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har inaktiverats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på nextcloud.com/enterprise.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 är den sista versionen som stödjer PHP 7.3. Nextcloud 24 kräver minst PHP 7.4.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" innehåller inte \"{expected}\". Det innebär en potentiell säkerhetsrisk. Det är rekommenderat att ändra inställningen.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Ett meddelande om lösenordsåterställning har skickats till e-postadressen för det här kontot. Om du får det, kontrollera dina spam/skräp -mappar eller fråga din lokala administratör om hjälp.",
    "If it is not there ask your local administrator." : "Om det inte finns, fråga din lokala administratör.",
    "Collaboratively edit office documents." : "Redigera dokument tillsammans.",
    "Local document editing back-end used by the Collabora Online app." : "Lokal dokumentredigering back-end som används av Collabora Online-appen.",
    "restricted" : "begränsad",
    "invisible" : "osynlig",
    "File not found" : "Filen kunde inte hittas",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentet kunde inte hittas på servern. Kanske var delningen raderad eller har gått ut?",
    "More" : "Mer",
    "More apps menu" : "Fler appar - meny",
    "Contacts" : "Kontakter",
    "Contacts menu" : "Kontaktmeny",
    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
    "Press enter to start searching" : "Tryck på enter för att börja söka"
},
"nplurals=2; plural=(n != 1);");
